@@ -188,7 +188,8 @@ class UBX_PORT_Frame(Frame):
         Reset panel to initial settings
         """
 
-        self._do_poll_prt()
+        if self.__app.serial_handler.connected:
+            self._do_poll_prt()
 
     def update_status(self, cfgtype, **kwargs):
         """
